{% load static bootstrap4 frontend_assets %}
<!doctype html>
<html lang="en">
<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <title>{% block title %}{% endblock %}</title>

    <!-- Bootstrap CSS -->
    {% bootstrap_css %}
    {% fontawesome5_css shim=True %}

    {% block extra_css %}{% endblock %}
</head>
<body>

{% block page_content %}{% endblock %}

<!-- Optional JavaScript -->
<!-- jQuery first, then Popper.js, then Bootstrap JS -->
{% bootstrap_javascript jquery='slim' %}
{% fontawesoe5_javascript shim=True %}

{% block extra_js %}{% endblock %}
</body>
</html>